@@ -50,7 +50,7 @@ package Astro::Coord::ECI::Star;
 use strict;
 use warnings;
 
-our $VERSION = '0.056_01';
+our $VERSION = '0.056_02';
 
 use base qw{Astro::Coord::ECI};
 
@@ -84,13 +84,13 @@ sub new {
 }
 
 
-=item @almanac = $star->almanac($location, $start, $end);
+=item @almanac = $star->almanac($station, $start, $end);
 
-This method produces almanac data for the star for the given location,
-between the given start and end times. The location is assumed to be
-Earth-Fixed - that is, you can not do this for something in orbit.
+This method produces almanac data for the star for the given observing
+station, between the given start and end times. The station is assumed
+to be Earth-Fixed - that is, you can not do this for something in orbit.
 
-The C<$location> argument may be omitted if the C<station> attribute has
+The C<$station> argument may be omitted if the C<station> attribute has
 been set. That is, this method can also be called as
 
  @almanac = $star->almanac( $start, $end )
@@ -140,7 +140,7 @@ sub __almanac_event_type_iterator {
 
 use Astro::Coord::ECI::Mixin qw{ almanac };
 
-=item @almanac = $star->almanac_hash($location, $start, $end);
+=item @almanac = $star->almanac_hash($station, $start, $end);
 
 This convenience method wraps $star->almanac(), but returns a list of
 hash references, sort of like Astro::Coord::ECI::TLE->pass()
@@ -317,6 +317,10 @@ Algorithms" (second edition) formed the basis for this module.
 
 =head1 SEE ALSO
 
+The C<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
+documentation for a discussion of how the pieces/parts of this
+distribution go together and how to use them.
+
 The B<Astro-Catalog> package by Alasdair Allan, which accommodates a
 much more fulsome description of a star. The star's coordinates are
 represented by an B<Astro::Coords> object.
@@ -344,3 +348,5 @@ without any warranty; without even the implied warranty of
 merchantability or fitness for a particular purpose.
 
 =cut
+
+# ex: set textwidth=72 :
