@@ -50,7 +50,7 @@ package Astro::Coord::ECI::Sun;
 use strict;
 use warnings;
 
-our $VERSION = '0.056_01';
+our $VERSION = '0.056_02';
 
 use base qw{Astro::Coord::ECI};
 
@@ -112,13 +112,13 @@ sub new {
 }
 
 
-=item @almanac = $sun->almanac( $location, $start, $end );
+=item @almanac = $sun->almanac( $station, $start, $end );
 
-This method produces almanac data for the Sun for the given location,
-between the given start and end times. The location is assumed to be
-Earth-Fixed - that is, you can't do this for something in orbit.
+This method produces almanac data for the Sun for the given observing
+station, between the given start and end times. The station is assumed
+to be Earth-Fixed - that is, you can't do this for something in orbit.
 
-The C<$location> argument may be omitted if the C<station> attribute has
+The C<$station> argument may be omitted if the C<station> attribute has
 been set. That is, this method can also be called as
 
  @almanac = $sun->almanac( $start, $end )
@@ -178,7 +178,7 @@ sub __almanac_event_type_iterator {
 
 use Astro::Coord::ECI::Mixin qw{ almanac };
 
-=item @almanac = $sun->almanac_hash( $location, $start, $end );
+=item @almanac = $sun->almanac_hash( $station, $start, $end );
 
 This convenience method wraps $sun->almanac(), but returns a list of
 hash references, sort of like Astro::Coord::ECI::TLE->pass()
@@ -461,6 +461,10 @@ Algorithms" (second edition) formed the basis for this module.
 
 =head1 SEE ALSO
 
+The C<Astro::Coord::ECI::OVERVIEW|Astro::Coord::ECI::OVERVIEW>
+documentation for a discussion of how the pieces/parts of this
+distribution go together and how to use them.
+
 The B<Astro-MoonPhase> package by Brett Hamilton, which contains a
 function-based module to compute the current phase, distance and
 angular diameter of the Moon, as well as the angular diameter and
